import { defu } from "defu";
import { appendHeader } from "h3";
import { createRouter as createRadixRouter, toRouteMatcher } from "radix3";
import { withoutBase } from "ufo";
import { getOgImagePath, separateProps, useOgImageRuntimeConfig, withoutQuery } from "../utils.mjs";
import { createOgImageMeta, normaliseOptions } from "../nuxt/utils.mjs";
import { useNuxtApp, useRequestEvent, useRoute, useRuntimeConfig } from "#imports";
export function defineOgImage(_options = {}) {
  if (!import.meta.server)
    return;
  const nuxtApp = useNuxtApp();
  const ogImageInstances = nuxtApp.ssrContext._ogImageInstances || [];
  const route = useRoute();
  const basePath = route.path || "/";
  const _routeRulesMatcher = toRouteMatcher(
    createRadixRouter({ routes: useRuntimeConfig().nitro?.routeRules })
  );
  const routeRules = defu({}, ..._routeRulesMatcher.matchAll(
    withoutBase(withoutQuery(basePath), useRuntimeConfig().app.baseURL)
  ).reverse()).ogImage;
  if (!_options || nuxtApp.ssrContext?.event.context._nitro?.routeRules?.ogImage === false || typeof routeRules !== "undefined" && routeRules === false) {
    ogImageInstances.forEach((e) => {
      e.dispose();
    });
    nuxtApp.ssrContext._ogImageInstances = void 0;
    return;
  }
  const options = normaliseOptions({
    ..._options
  });
  if (route.query)
    options._query = route.query;
  const { defaults } = useOgImageRuntimeConfig();
  const resolvedOptions = normaliseOptions(defu(separateProps(_options), separateProps(routeRules), defaults));
  if (_options.url) {
    createOgImageMeta(null, options, resolvedOptions, nuxtApp.ssrContext);
  } else {
    const path = getOgImagePath(basePath, resolvedOptions);
    if (import.meta.prerender)
      appendHeader(useRequestEvent(), "x-nitro-prerender", path);
    createOgImageMeta(path, options, resolvedOptions, nuxtApp.ssrContext);
  }
}
