import { defu } from "defu";
import { normaliseFontInput, useOgImageRuntimeConfig } from "../../../utils.mjs";
import { loadFont } from "../../font/fetch.mjs";
import { fontCache, fontPromises } from "../../cache/fonts.mjs";
import { createVNodes } from "./vnodes.mjs";
import { useResvg, useSatori, useSharp } from "./instances.mjs";
import { theme } from "#nuxt-og-image/unocss-config.mjs";
export async function createSvg(event) {
  const { options } = event;
  const { fonts, satoriOptions } = useOgImageRuntimeConfig();
  const vnodes = await createVNodes(event);
  await event._nitro.hooks.callHook("nuxt-og-image:satori:vnodes", vnodes, event);
  const normalisedFonts = normaliseFontInput([...fonts, ...event.options.fonts || []]);
  const localFontPromises = [];
  const preloadedFonts = [];
  for (const font of normalisedFonts) {
    if (await fontCache.hasItem(font.cacheKey)) {
      font.data = await fontCache.getItemRaw(font.cacheKey);
      preloadedFonts.push(font);
    } else {
      if (!fontPromises[font.cacheKey]) {
        fontPromises[font.cacheKey] = loadFont(event, font).then(async (_font) => {
          if (_font?.data)
            await fontCache.setItemRaw(_font.cacheKey, _font.data);
          return _font;
        });
      }
      localFontPromises.push(fontPromises[font.cacheKey]);
    }
  }
  const awaitedFonts = await Promise.all(localFontPromises);
  const satori = await useSatori();
  return satori(vnodes, defu(options.satori, satoriOptions, {
    fonts: [...preloadedFonts, ...awaitedFonts].map((_f) => {
      return { ..._f, weight: Number(_f.weight) };
    }),
    tailwindConfig: { theme },
    embedFont: true,
    width: options.width,
    height: options.height
  }));
}
async function createPng(event) {
  const { resvgOptions } = useOgImageRuntimeConfig();
  const svg = await createSvg(event);
  const Resvg = await useResvg();
  const resvg = new Resvg(svg, defu(
    event.options.resvg,
    resvgOptions
  ));
  const pngData = resvg.render();
  return pngData.asPng();
}
async function createJpeg(event) {
  const { sharpOptions } = useOgImageRuntimeConfig();
  const png = await createPng(event);
  const sharp = await useSharp();
  return sharp(png, defu(event.options.sharp, sharpOptions)).jpeg().toBuffer();
}
const SatoriRenderer = {
  name: "satori",
  supportedFormats: ["png", "jpeg", "jpg", "json"],
  async createImage(e) {
    switch (e.extension) {
      case "png":
        return createPng(e);
      case "jpeg":
      case "jpg":
        return createJpeg(e);
    }
  },
  async debug(e) {
    return {
      vnodes: await createVNodes(e),
      svg: await createSvg(e)
    };
  }
};
export default SatoriRenderer;
