import { Buffer } from "node:buffer";
import { withBase } from "ufo";
import sizeOf from "image-size";
import { defineSatoriTransformer } from "../utils.mjs";
import { toBase64Image } from "../../../env/assets.mjs";
import { useStorage } from "#internal/nitro";
import { useNitroOrigin } from "#imports";
export default defineSatoriTransformer([
  // fix <img src="">
  {
    filter: (node) => node.type === "img",
    transform: async (node, { e }) => {
      const src = node.props?.src;
      const isRelative = src?.startsWith("/");
      if (src) {
        let updated = false;
        let dimensions;
        let imageBuffer;
        let valid = true;
        if (import.meta.prerender || import.meta.dev) {
          const key = `root:public${src.replace("./", ":").replace("/", ":")}`;
          if (await useStorage().hasItem(key)) {
            imageBuffer = await useStorage().getItemRaw(key);
            updated = !!imageBuffer;
          }
        }
        if (!import.meta.prerender && !updated) {
          imageBuffer = await e.$fetch(src, {
            baseURL: useNitroOrigin(e),
            responseType: "arrayBuffer"
          }).catch(() => {
            valid = false;
          });
          valid = !!imageBuffer;
        }
        if (valid) {
          node.props.src = toBase64Image(src, imageBuffer);
          try {
            const imageSize = sizeOf(Buffer.from(imageBuffer));
            dimensions = { width: imageSize.width, height: imageSize.height };
          } catch (e2) {
          }
          updated = true;
        }
        if (dimensions?.width && dimensions?.height) {
          const naturalAspectRatio = dimensions.width / dimensions.height;
          if (node.props.width && !node.props.height) {
            node.props.height = Math.round(node.props.width / naturalAspectRatio);
          } else if (node.props.height && !node.props.width) {
            node.props.width = Math.round(node.props.height * naturalAspectRatio);
          } else if (!node.props.width && !node.props.height) {
            node.props.width = dimensions.width;
            node.props.height = dimensions.height;
          }
        }
        if (!updated && isRelative) {
          node.props.src = `${withBase(src, `${useNitroOrigin(e)}`)}?${Date.now()}`;
        }
      }
    }
  },
  // fix style="background-image: url('')"
  {
    filter: (node) => node.props?.style?.backgroundImage?.includes("url("),
    transform: async (node, { e }) => {
      const backgroundImage = node.props.style.backgroundImage;
      if (backgroundImage) {
        const src = backgroundImage.replace(/^url\(['"]?/, "").replace(/['"]?\)$/, "");
        const isRelative = src?.startsWith("/");
        if (isRelative)
          node.props.style.backgroundImage = `url(${withBase(src, `${useNitroOrigin(e)}`)}?${Date.now()})`;
      }
    }
  }
]);
