import { html as convertHtmlToSatori } from "satori-html";
import { fetchIsland } from "../../html/fetchIsland.mjs";
import { applyInlineCss } from "../../html/applyInlineCss.mjs";
import { applyEmojis } from "../../html/applyEmojis.mjs";
import { walkSatoriTree } from "./utils.mjs";
import unocss from "./plugins/unocss.mjs";
import emojis from "./plugins/emojis.mjs";
import twClasses from "./plugins/twClasses.mjs";
import imageSrc from "./plugins/imageSrc.mjs";
import flex from "./plugins/flex.mjs";
import encoding from "./plugins/encoding.mjs";
export async function createVNodes(ctx) {
  let html = ctx.options.html;
  if (!html) {
    const island = await fetchIsland(ctx);
    await applyInlineCss(ctx, island);
    await applyEmojis(ctx, island);
    html = island.html;
  }
  const template = `<div data-v-inspector-ignore="true" style="position: relative; display: flex; margin: 0 auto; width: ${ctx.options.width}px; height: ${ctx.options.height}px; overflow: hidden;">${html}</div>`;
  const satoriTree = convertHtmlToSatori(template);
  await walkSatoriTree(ctx, satoriTree, [
    unocss,
    emojis,
    twClasses,
    imageSrc,
    flex,
    encoding
  ]);
  return satoriTree;
}
