import { parseURL, withoutBase } from "ufo";
import { defineNitroPlugin } from "nitropack/dist/runtime/plugin";
import { createRouter as createRadixRouter, toRouteMatcher } from "radix3";
import { defu } from "defu";
import { extractAndNormaliseOgImageOptions } from "../../core/options/extract.mjs";
import { prerenderOptionsCache } from "../../core/cache/prerender.mjs";
import { isInternalRoute } from "../../utils.pure.mjs";
import { resolvePathCacheKey } from "../utils.mjs";
import { useRuntimeConfig } from "#internal/nitro";
export default defineNitroPlugin(async (nitro) => {
  if (!import.meta.prerender)
    return;
  nitro.hooks.hook("render:html", async (html, ctx) => {
    const { head, bodyAppend } = html;
    const path = parseURL(ctx.event.path).pathname;
    if (isInternalRoute(path))
      return;
    const runtimeConfig = useRuntimeConfig();
    const _routeRulesMatcher = toRouteMatcher(
      createRadixRouter({ routes: runtimeConfig.nitro?.routeRules })
    );
    const routeRules = defu({}, ..._routeRulesMatcher.matchAll(
      withoutBase(path.split("?")[0], runtimeConfig.app.baseURL)
    ).reverse()).ogImage;
    if (routeRules === false)
      return;
    const options = extractAndNormaliseOgImageOptions([
      head.join("\n"),
      bodyAppend.join("\n")
    ].join("\n"));
    if (!options)
      return;
    const key = resolvePathCacheKey(ctx.event);
    await prerenderOptionsCache.setItem(key, options);
  });
});
